@@ -10,11 +10,12 @@ import matplotlib as mpl
 import matplotlib.colors as mplcol
 import matplotlib.pyplot as plt
 
+from .external.six.moves.urllib.request import urlopen, urlretrieve
+from .external.six.moves.http_client import HTTPException
+
 from distutils.version import LooseVersion
 pandas_has_categoricals = LooseVersion(pd.__version__) >= "0.15"
 mpl_ge_150 = LooseVersion(mpl.__version__) >= "1.5.0"
-from .external.six.moves.urllib.request import urlopen, urlretrieve
-from .external.six.moves.http_client import HTTPException
 
 
 __all__ = ["desaturate", "saturate", "set_hls_values",
@@ -38,6 +39,14 @@ def remove_na(arr):
     return arr[pd.notnull(arr)]
 
 
+def sort_df(df, *args, **kwargs):
+    """Wrapper to handle different pandas sorting API pre/post 0.17."""
+    try:
+        return df.sort_values(*args, **kwargs)
+    except AttributeError:
+        return df.sort(*args, **kwargs)
+
+
 def ci_to_errsize(cis, heights):
     """Convert intervals to error arguments relative to plot heights.
 
@@ -146,7 +155,7 @@ def saturate(color):
     return set_hls_values(color, s=1)
 
 
-def set_hls_values(color, h=None, l=None, s=None):
+def set_hls_values(color, h=None, l=None, s=None):  # noqa
     """Independently manipulate the h, l, or s channels of a color.
 
     Parameters
@@ -224,15 +233,24 @@ def despine(fig=None, ax=None, top=True, right=True, left=False,
                     val = offset
                 _set_spine_position(ax_i.spines[side], ('outward', val))
 
-        # Set the ticks appropriately
-        if bottom:
-            ax_i.xaxis.tick_top()
-        if top:
-            ax_i.xaxis.tick_bottom()
-        if left:
-            ax_i.yaxis.tick_right()
-        if right:
-            ax_i.yaxis.tick_left()
+        # Potentially move the ticks
+        if left and not right:
+            maj_on = any(t.tick1On for t in ax_i.yaxis.majorTicks)
+            min_on = any(t.tick1On for t in ax_i.yaxis.minorTicks)
+            ax_i.yaxis.set_ticks_position("right")
+            for t in ax_i.yaxis.majorTicks:
+                t.tick2On = maj_on
+            for t in ax_i.yaxis.minorTicks:
+                t.tick2On = min_on
+
+        if bottom and not top:
+            maj_on = any(t.tick1On for t in ax_i.xaxis.majorTicks)
+            min_on = any(t.tick1On for t in ax_i.xaxis.minorTicks)
+            ax_i.xaxis.set_ticks_position("top")
+            for t in ax_i.xaxis.majorTicks:
+                t.tick2On = maj_on
+            for t in ax_i.xaxis.minorTicks:
+                t.tick2On = min_on
 
         if trim:
             # clip off the parts of the spines that extend past major ticks
@@ -521,6 +539,7 @@ def categorical_order(values, order=None):
 
 
 def get_color_cycle():
+    """Return the list of colors in the current matplotlib color cycle."""
     if mpl_ge_150:
         cyl = mpl.rcParams['axes.prop_cycle']
         # matplotlib 1.5 verifies that axes.prop_cycle *is* a cycler
@@ -530,6 +549,7 @@ def get_color_cycle():
             return [x['color'] for x in cyl]
         except KeyError:
             pass  # just return axes.color style below
+
     return mpl.rcParams['axes.color_cycle']
 
 
@@ -605,7 +625,7 @@ def to_utf8(obj):
             return obj.__str__()
 
 
-def _network(t=None, url='http://google.com'):
+def _network(t=None, url='https://google.com'):
     """
     Decorator that will skip a test if `url` is unreachable.
 
